"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SWC_VERSION = exports.transform = exports.transformJest = exports.transformSync = void 0;
const os_1 = require("os");
const path_1 = require("path");
const helper_1 = require("@node-rs/helper");
let bindings;
let linuxError = null;
try {
    bindings = helper_1.loadBinding(path_1.join(require.resolve('@swc-node/core'), '..', '..'), 'swc');
}
catch (e) {
    const platformName = os_1.platform();
    try {
        bindings = require(`@swc-node/core-${platformName}`);
    }
    catch (e) {
        if (platformName !== 'linux') {
            throw new TypeError('Not compatible with your platform. Error message: ' + e.message);
        }
        else {
            linuxError = e;
        }
    }
}
if (!bindings) {
    try {
        require.resolve('@swc-node/core-linux-musl');
    }
    catch (e) {
        throw new TypeError(`Could not load @swc-node/core-linux-musl, You may need add @swc-node/core-linux-musl to optionalDependencies of your project`);
    }
    try {
        bindings = require('@swc-node/core-linux-musl');
    }
    catch (e) {
        throw new TypeError(`Linux glibc version load error: ${linuxError.message}; Linux musl version load error: Error message: ${e.message}`);
    }
}
function transformOption(path, options) {
    var _a, _b;
    const opts = options == null ? {} : options;
    return Buffer.from(JSON.stringify({
        filename: path,
        jsc: {
            target: (_a = opts.target) !== null && _a !== void 0 ? _a : 'es2018',
            parser: {
                syntax: 'typescript',
                tsx: typeof opts.jsx !== 'undefined' ? opts.jsx : path.endsWith('.tsx'),
                decorators: Boolean(opts.experimentalDecorators),
                dynamicImport: Boolean(opts.dynamicImport),
            },
            transform: {
                legacyDecorator: Boolean(opts.experimentalDecorators),
                decoratorMetadata: Boolean(opts.emitDecoratorMetadata),
            },
        },
        isModule: true,
        module: {
            type: (_b = opts.module) !== null && _b !== void 0 ? _b : 'commonjs',
        },
        sourceMaps: typeof opts.sourcemap === 'undefined' ? true : opts.sourcemap,
        swcrc: false,
    }));
}
function transformSync(source, path, options) {
    return bindings.transformSync(source, path, transformOption(path, options));
}
exports.transformSync = transformSync;
function transformJest(source, path, options) {
    return bindings.transformJest(source, path, transformOption(path, options));
}
exports.transformJest = transformJest;
function transform(source, path, options) {
    return bindings.transform(source, path, transformOption(path, options));
}
exports.transform = transform;
exports.SWC_VERSION = '1.2.21';
//# sourceMappingURL=index.js.map